@@ -1,10 +1,10 @@
 #include "dummykernel.h"
 
-#include <AkonadiCore/changerecorder.h>
-#include <AkonadiCore/entitymimetypefiltermodel.h>
-#include <AkonadiCore/entitytreemodel.h>
-#include <AkonadiCore/session.h>
-#include <KIdentityManagement/kidentitymanagement/identitymanager.h>
+#include <Akonadi/ChangeRecorder>
+#include <Akonadi/EntityMimeTypeFilterModel>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/Session>
+#include <KIdentityManagement/IdentityManager>
 #include <KSharedConfig>
 #include <MailCommon/FolderCollectionMonitor>
 #include <MessageComposer/AkonadiSender>
@@ -90,7 +90,7 @@ qreal DummyKernel::closeToQuotaThreshold()
 QStringList DummyKernel::customTemplates()
 {
     Q_ASSERT(false);
-    return QStringList();
+    return {};
 }
 
 bool DummyKernel::excludeImportantMailFromExpiry()
