@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
   SPDX-FileCopyrightText: 2013 Jonathan Marten <jjm@keelhaul.me.uk>
 
   SPDX-License-Identifier: GPL-2.0-only
@@ -27,9 +27,7 @@ CollectionExpiryPage::CollectionExpiryPage(QWidget *parent)
     setPageTitle(i18nc("@title:tab Expiry settings for a folder.", "Expiry"));
 }
 
-CollectionExpiryPage::~CollectionExpiryPage()
-{
-}
+CollectionExpiryPage::~CollectionExpiryPage() = default;
 
 bool CollectionExpiryPage::canHandle(const Akonadi::Collection &col) const
 {
@@ -58,7 +56,8 @@ void CollectionExpiryPage::load(const Akonadi::Collection &collection)
     init();
     const auto *attr = collection.attribute<MailCommon::ExpireCollectionAttribute>();
     if (attr) {
-        int daysToExpireRead, daysToExpireUnread;
+        int daysToExpireRead;
+        int daysToExpireUnread;
         attr->daysToExpire(daysToExpireUnread, daysToExpireRead);
         MailCommon::CollectionExpirySettings settings;
         settings.expiryGloballyOn = attr->isAutoExpire();
