@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -13,9 +13,7 @@ MailFilterTest::MailFilterTest(QObject *parent)
 {
 }
 
-MailFilterTest::~MailFilterTest()
-{
-}
+MailFilterTest::~MailFilterTest() = default;
 
 void MailFilterTest::shouldHaveDefaultValue()
 {
