@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,9 +8,9 @@
 #include "filter/filterlog.h"
 using MailCommon::FilterLog;
 
-#include <Akonadi/Contact/ContactSearchJob>
+#include <Akonadi/ContactSearchJob>
 
-#include <AkonadiCore/SearchQuery>
+#include <Akonadi/SearchQuery>
 
 #include <KMime/KMimeMessage>
 
@@ -21,7 +21,6 @@ using MailCommon::FilterLog;
 #include <QRegularExpression>
 
 #include <algorithm>
-#include <boost/bind.hpp>
 
 using namespace MailCommon;
 SearchRuleString::SearchRuleString(const QByteArray &field, Function func, const QString &contents)
@@ -30,9 +29,8 @@ SearchRuleString::SearchRuleString(const QByteArray &field, Function func, const
 }
 
 SearchRuleString::SearchRuleString(const SearchRuleString &other)
-    : SearchRule(other)
-{
-}
+
+    = default;
 
 const SearchRuleString &SearchRuleString::operator=(const SearchRuleString &other)
 {
@@ -47,9 +45,7 @@ const SearchRuleString &SearchRuleString::operator=(const SearchRuleString &othe
     return *this;
 }
 
-SearchRuleString::~SearchRuleString()
-{
-}
+SearchRuleString::~SearchRuleString() = default;
 
 bool SearchRuleString::isEmpty() const
 {
@@ -153,6 +149,20 @@ bool SearchRuleString::matches(const Akonadi::Item &item) const
     }
 
     bool rc = matchesInternal(msgContents);
+    if (!rc) {
+        // Try to search endwith for emails => remove >
+        // Bug 455273
+        if ((qstricmp(field().constData(), "to") == 0) || (qstricmp(field().constData(), "cc") == 0) || (qstricmp(field().constData(), "bcc") == 0)
+            || (qstricmp(field().constData(), "from") == 0) || (qstricmp(field().constData(), "reply-to") == 0)) {
+            if (function() == SearchRule::FuncEndWith || function() == SearchRule::FuncNotEndWith) {
+                QString newContents = msgContents;
+                if (newContents.endsWith(QLatin1Char('>'))) {
+                    newContents.chop(1);
+                    rc = matchesInternal(newContents);
+                }
+            }
+        }
+    }
     if (FilterLog::instance()->isLogging()) {
         QString msgStr = (rc ? QStringLiteral("<font color=#00FF00>1 = </font>") : QStringLiteral("<font color=#FF0000>0 = </font>"));
         msgStr += FilterLog::recode(asString());
